/**
 * @module package/quiqqer/adblock-detection/bin/detection
 * @author www.pcsg.de (Henning Leutz)
 */
define('package/quiqqer/adblock-detection/bin/detection', [

    'Locale',

    'css!package/quiqqer/adblock-detection/bin/detection.css'

], function (QUILocale) {
    "use strict";

    var lg        = 'quiqqer/adblock-detection';
    var canRunAds = null;

    return {

        /**
         * parse all add places and fill it with add block detection
         */
        parse: function () {
            var self     = this;
            var elements = document.querySelectorAll('[data-ad-detection]');

            this.canRunAds().then(function (canRun) {
                if (canRun) {
                    return;
                }

                elements.forEach(function (elm) {
                    var Hint = self.createHint();

                    elm.appendChild(Hint);

                    if (elm.nodeName === 'BODY') {
                        Hint.classList.add('body-ad-detection');
                        return;
                    }

                    elm.style.position = 'relative';

                    var size = elm.getSize();

                    if (size.x < 400 || size.y < 150) {
                        elm.classList.add('ad-detection-container--no-icon');
                    }
                });
            });
        },

        /**
         * Add block on or off?
         *
         * @return {Promise}
         */
        canRunAds: function () {
            if (canRunAds !== null) {
                return Promise.resolve(canRunAds);
            }

            return new Promise(function (resolve) {
                try {
                    require(['package/quiqqer/adblock-detection/bin/ads'], function (ads) {
                        canRunAds = ads();
                        resolve(canRunAds);
                    }, function () {
                        canRunAds = false;
                        resolve(canRunAds);
                    });
                } catch (e) {
                    canRunAds = false;
                    resolve(canRunAds);
                }
            });
        },

        /**
         * Create a ad detection hint
         *
         * @return {HTMLDivElement}
         */
        createHint: function () {
            var Hint = document.createElement('section');
            Hint.classList.add('ad-detection');

            var Container = document.createElement('div');
            Container.classList.add('ad-detection-container');
            Hint.appendChild(Container);

            var Icon = document.createElement('span');
            Icon.classList.add('ad-detection-container-icon');
            Icon.classList.add('fa');
            Icon.classList.add('fa-ban');
            Container.appendChild(Icon);

            var Text = document.createElement('div');
            Text.classList.add('ad-detection-container-text');
            Text.innerHTML = QUILocale.get(lg, 'adblock.message');
            Container.appendChild(Text);

            return Hint;
        }
    };
});

require(['package/quiqqer/adblock-detection/bin/detection'], function (Detection) {
    "use strict";

    Detection.parse();
});
